==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesTy.php <==
<?php
/** Tahitian (Reo Mā`ohi)
 *
 * @addtogroup Language
 *
 * @author SPQRobin
 * @author Sab
 */

$fallback = 'fr';

$messages = array(
# Dates
'sunday'        => 'tāpati',
'monday'        => 'monirē',
'tuesday'       => 'mahana piti',
'wednesday'     => 'mahana toru',
'thursday'      => 'mahana maha',
'friday'        => 'mahana pae',
'saturday'      => 'mahana mā’a',
'sun'           => 'tāpati',
'mon'           => 'monirē',
'tue'           => 'mahana piti',
'wed'           => 'mahana toru',
'thu'           => 'mahana maha',
'fri'           => 'mahana pae',
'sat'           => 'mahana mā’a',
'january'       => 'nō tēnuare',
'february'      => 'nō fepuare',
'march'         => 'nō māti',
'april'         => 'nō ’ēperēra',
'may_long'      => 'nō mē',
'june'          => 'nō tiunu',
'july'          => 'nō tiurai',
'august'        => 'nō tiurai',
'september'     => 'nō tetepa',
'october'       => 'nō ’ātopa',
'november'      => 'nō novema',
'december'      => 'nō tītema',
'january-gen'   => 'nō tēnuare',
'february-gen'  => 'nō fepuare',
'march-gen'     => 'nō māti',
'april-gen'     => 'nō ’ēperēra',
'may-gen'       => 'nō mē',
'june-gen'      => 'nō tiunu',
'july-gen'      => 'nō tiurai',
'august-gen'    => 'nō tiurai',
'september-gen' => 'nō tetepa',
'october-gen'   => 'nō ’ātopa',
'november-gen'  => 'nō novema',
'december-gen'  => 'nō tītema',
'jan'           => 'nō tēnuare',
'feb'           => 'nō fepuare',
'mar'           => 'nō māti',
'apr'           => 'nō ’ēperēra',
'may'           => 'nō mē',
'jun'           => 'nō tiunu',
'jul'           => 'nō tiurai',
'aug'           => 'nō tiurai',
'sep'           => 'nō tetepa',
'oct'           => 'nō ’ātopa',
'nov'           => 'nō novema',
'dec'           => 'nō tītema',

# Bits of text used by many pages
'categories' => 'Te mau huru o te ’api',

'about'          => 'Nō',
'article'        => 'Parau pāpa’i',
'qbedit'         => 'Fa’ahuru ’ē',
'qbmyoptions'    => 'ta’u ’api',
'qbspecialpages' => 'Te mau ’api ta’a ’ē',
'navigation'     => 'Arata’i',

'help'             => 'Tauturu',
'search'           => 'Roromā’imi',
'searchbutton'     => 'Roromā’imi',
'searcharticle'    => 'Haere',
'history_short'    => 'Parau tuatāpapa',
'edit'             => 'Fa’ahuru ’ē',
'delete'           => 'Fa’a’ore',
'protect'          => 'Pāruru',
'specialpage'      => '’Api ta’a ’ē',
'talk'             => 'Paraparaura’a',
'jumptonavigation' => 'arata’i',
'jumptosearch'     => 'haere',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'   => 'Nō {{SITENAME}}',
'aboutpage'   => 'Project:Nō',
'edithelp'    => 'Tauturu',
'mainpage'    => 'Fa’ari’ira’a',
'portal'      => 'Fare auhoa',
'sitesupport' => 'Pūpū i te ō',

'newmessageslink'     => 'Te mau poro’i ’āpī',
'newmessagesdifflink' => 'fa’ahuru-’ē-ra’a hope’a',
'editsection'         => 'fa’ahuru ’ē',
'editold'             => 'fa’ahuru ’ē',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Parau pāpa’i',
'nstab-user'      => 'Ta’ata',
'nstab-special'   => 'Ta’a ’ē',
'nstab-image'     => 'Hōho’a',
'nstab-mediawiki' => 'Poro’i',
'nstab-template'  => 'Hōho’a fāito',
'nstab-help'      => 'Tauturu',
'nstab-category'  => 'Huru',

# Login and logout pages
'youremail'    => 'Tā’u ’āfata rata uira',
'yourlanguage' => 'Te reo:',
'email'        => '’Imere',

# Revision feed
'history-feed-title' => 'Parau tuatāpapa',

# Search results
'powersearch' => 'Roromā’imi',

# Preferences page
'prefs-rc' => 'Te mau fa’ahuru-’ē-ra’a ’āpī',
'files'    => 'Te mau putu’ite',

# Recent changes
'recentchanges' => 'Te mau fa’ahuru-’ē-ra’a ’āpī',

# Image list
'filehist-user'  => 'Ta’ata',
'imagelist_user' => 'Ta’ata fa’a’ohipa',

# Random page
'randompage' => '’Api mā’iti-haere-noa',

# Miscellaneous special pages
'specialpages' => 'Te mau ’api ta’a ’ē',
'spheading'    => 'Te mau ’api ta’a ’ē',

# Special:Log
'specialloguserlabel' => 'Ta’ata fa’a’ohipa :',

# Special:Allpages
'allpagessubmit' => 'Haere',

# Watchlist
'watch' => 'Ha’apa’o',

# Restrictions (nouns)
'restriction-edit' => 'Fa’ahuru ’ē',
'restriction-move' => 'Tāhiti',

# What links here
'whatlinkshere' => 'Te mau ’api i tū’atihia mai',

# Move page
'1movedto2' => '’Ua tāhitihia te ’api [[$1]] e ana i te ’api ’āpī [[$2]]',

# Tooltip help for the actions
'tooltip-search' => 'Roromā’imi {{SITENAME}}',

# Special:Filepath
'filepath-page' => 'Putu’ite:',

);

==> mediawiki-1.14.0.tar.gz: mediawiki-1.14.0/languages/messages/MessagesTy.php <==
<?php
/** Tahitian (Reo Mā`ohi)
 *
 * @ingroup Language
 * @file
 *
 * @author Sab
 */

$fallback = 'fr';

$messages = array(
# Dates
'sunday'        => 'tāpati',
'monday'        => 'monirē',
'tuesday'       => 'mahana piti',
'wednesday'     => 'mahana toru',
'thursday'      => 'mahana maha',
'friday'        => 'mahana pae',
'saturday'      => 'mahana mā’a',
'sun'           => 'tāpati',
'mon'           => 'monirē',
'tue'           => 'mahana piti',
'wed'           => 'mahana toru',
'thu'           => 'mahana maha',
'fri'           => 'mahana pae',
'sat'           => 'mahana mā’a',
'january'       => 'nō tēnuare',
'february'      => 'nō fepuare',
'march'         => 'nō māti',
'april'         => 'nō ’ēperēra',
'may_long'      => 'nō mē',
'june'          => 'nō tiunu',
'july'          => 'nō tiurai',
'august'        => 'nō tiurai',
'september'     => 'nō tetepa',
'october'       => 'nō ’ātopa',
'november'      => 'nō novema',
'december'      => 'nō tītema',
'january-gen'   => 'nō tēnuare',
'february-gen'  => 'nō fepuare',
'march-gen'     => 'nō māti',
'april-gen'     => 'nō ’ēperēra',
'may-gen'       => 'nō mē',
'june-gen'      => 'nō tiunu',
'july-gen'      => 'nō tiurai',
'august-gen'    => 'nō tiurai',
'september-gen' => 'nō tetepa',
'october-gen'   => 'nō ’ātopa',
'november-gen'  => 'nō novema',
'december-gen'  => 'nō tītema',
'jan'           => 'nō tēnuare',
'feb'           => 'nō fepuare',
'mar'           => 'nō māti',
'apr'           => 'nō ’ēperēra',
'may'           => 'nō mē',
'jun'           => 'nō tiunu',
'jul'           => 'nō tiurai',
'aug'           => 'nō tiurai',
'sep'           => 'nō tetepa',
'oct'           => 'nō ’ātopa',
'nov'           => 'nō novema',
'dec'           => 'nō tītema',

'about'          => 'Nō',
'article'        => 'Parau pāpa’i',
'qbedit'         => 'Fa’ahuru ’ē',
'qbmyoptions'    => 'ta’u ’api',
'qbspecialpages' => 'Te mau ’api ta’a ’ē',
'navigation'     => 'Arata’i',

'help'             => 'Tauturu',
'search'           => 'Roromā’imi',
'searchbutton'     => 'Roromā’imi',
'searcharticle'    => 'Haere',
'history_short'    => 'Parau tuatāpapa',
'edit'             => 'Fa’ahuru ’ē',
'delete'           => 'Fa’a’ore',
'protect'          => 'Pāruru',
'specialpage'      => '’Api ta’a ’ē',
'talk'             => 'Paraparaura’a',
'jumptonavigation' => 'arata’i',
'jumptosearch'     => 'haere',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Nō {{SITENAME}}',
'aboutpage'            => 'Project:Nō',
'edithelp'             => 'Tauturu',
'mainpage'             => 'Fa’ari’ira’a',
'mainpage-description' => 'Fa’ari’ira’a',
'portal'               => 'Fare auhoa',

'newmessageslink'     => 'Te mau poro’i ’āpī',
'newmessagesdifflink' => 'fa’ahuru-’ē-ra’a hope’a',
'editsection'         => 'fa’ahuru ’ē',
'editold'             => 'fa’ahuru ’ē',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Parau pāpa’i',
'nstab-user'      => 'Ta’ata',
'nstab-special'   => 'Ta’a ’ē',
'nstab-image'     => 'Hōho’a',
'nstab-mediawiki' => 'Poro’i',
'nstab-template'  => 'Hōho’a fāito',
'nstab-help'      => 'Tauturu',
'nstab-category'  => 'Huru',

# Login and logout pages
'youremail'    => 'Tā’u ’āfata rata uira',
'yourlanguage' => 'Te reo:',
'email'        => '’Imere',

# Revision feed
'history-feed-title' => 'Parau tuatāpapa',

# Search results
'powersearch' => 'Roromā’imi',

# Preferences page
'prefs-rc' => 'Te mau fa’ahuru-’ē-ra’a ’āpī',
'files'    => 'Te mau putu’ite',

# Recent changes
'recentchanges' => 'Te mau fa’ahuru-’ē-ra’a ’āpī',

# Special:ListFiles
'listfiles_user' => 'Ta’ata fa’a’ohipa',

# File description page
'filehist-user' => 'Ta’ata',

# Random page
'randompage' => '’Api mā’iti-haere-noa',

# Special:Log
'specialloguserlabel' => 'Ta’ata fa’a’ohipa :',

# Special:AllPages
'allpagessubmit' => 'Haere',

# Special:Categories
'categories' => 'Te mau huru o te ’api',

# Special:Log/newusers
'newuserlog-create-entry' => 'Ta’ata fa’a’ohipa ’āpī',

# Watchlist
'watch' => 'Ha’apa’o',

# Protect
'prot_1movedto2' => '’Ua tāhitihia te ’api [[$1]] e ana i te ’api ’āpī [[$2]]',

# Restrictions (nouns)
'restriction-edit' => 'Fa’ahuru ’ē',
'restriction-move' => 'Tāhiti',

# What links here
'whatlinkshere' => 'Te mau ’api i tū’atihia mai',

# Move page
'1movedto2' => '’Ua tāhitihia te ’api [[$1]] e ana i te ’api ’āpī [[$2]]',

# Tooltip help for the actions
'tooltip-search' => 'Roromā’imi {{SITENAME}}',

# Special:FilePath
'filepath-page' => 'Putu’ite:',

# Special:SpecialPages
'specialpages' => 'Te mau ’api ta’a ’ē',

);
